@@ -1,5 +1,3 @@
-import requests
-
 from formaloo import constants, client
 
 
@@ -13,22 +11,22 @@ class ActivityBatch:
         self.activities.append(activity)
 
     def create(self):
-        headers = self.client.get_headers()
         body = self.get_body()
 
-        response = requests.post(
+        response = self.client.post(
             constants.V_1_0_ACTIVITY_BATCH_ENDPOINT,
-            headers=headers,
-            data=body
+            body=body
         )
 
-        return response
+        return response.json()
 
     def get_body(self):
-        body = []
+        body = {
+            'activities_data': []
+        }
 
         for activity in self.activities:
-            body.append(
+            body['activities_data'].append(
                 activity.get_body()
             )
 
