@@ -1,11 +1,12 @@
-import requests
-
 from formaloo import constants, client
 
 
 class CustomerBatch:
 
-    def __init__(self, customers=[]):
+    def __init__(self, customers=None):
+        if not customers:
+            customers = []
+
         self.client = client.Client()
         self.customers = customers
 
@@ -13,22 +14,22 @@ class CustomerBatch:
         self.customers.append(customer)
 
     def create(self):
-        headers = self.client.get_headers()
         body = self.get_body()
 
-        response = requests.post(
+        response = self.client.post(
             constants.V_1_0_CUSTOMER_BATCH_ENDPOINT,
-            headers=headers,
-            data=body
+            body=body
         )
 
-        return response
+        return response.json()
 
     def get_body(self):
-        body = []
+        body = {
+            'customers_data': []
+        }
 
         for customer in self.customers:
-            body.append(
+            body['customers_data'].append(
                 customer.get_body()
             )
 
